#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 safecopy
version:              0.10.4.2
visibility:           public
id:                   safecopy-0.10.4.2-7054Px5Ep703v1r6udTtR5
key:                  safecopy-0.10.4.2-7054Px5Ep703v1r6udTtR5
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>, David Fox <dsf@seereason.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  a1289ce142c530937b4a36a0e6d686bb
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-8.10.5/site-local/safecopy-0.10.4.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/safecopy-0.10.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/safecopy-0.10.4.2
hs-libraries:         HSsafecopy-0.10.4.2-7054Px5Ep703v1r6udTtR5
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0
    cereal-0.5.8.1-4r85zOZIbEW4fo8WFnBuTl containers-0.6.4.1
    generic-data-0.9.2.0-DBn5MUVniC2Jz9xtBoXCJa
    old-time-1.1.0.3-L4487sR2g8B3hwiiVWHb93 template-haskell-2.16.0.0
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

